@@ -92,6 +92,7 @@ int	peer_free_count;		/* count of free structures */
  * value every time an association is mobilized.
  */
 static associd_t current_association_ID; /* association ID */
+static associd_t initial_association_ID; /* association ID */
 
 /*
  * Memory allocation watermarks.
@@ -147,6 +148,7 @@ init_peer(void)
 	do
 		current_association_ID = ntp_random() & ASSOCID_MAX;
 	while (!current_association_ID);
+	initial_association_ID = current_association_ID;
 }
 
 
@@ -540,9 +542,8 @@ unpeer(
 	if (FLAG_REFCLOCK & peer->flags)
 		refclock_unpeer(peer);
 #endif
-	peer->action = NULL;	/* disable timeout actions */
 
-	free_peer(peer, 1);
+	free_peer(peer, TRUE);
 }
 
 
@@ -763,7 +764,7 @@ newpeer(
 	/*
 	 * For now only pool associations have a hostname.
 	 */
-	NTP_INSIST(NULL == hostname || (MDF_POOL & cast_flags));
+	INSIST(NULL == hostname || (MDF_POOL & cast_flags));
 
 	/*
 	 * First search from the beginning for an association with given
@@ -906,9 +907,8 @@ newpeer(
 	peer->timereachable = current_time;
 	peer->timereceived = current_time;
 
-#ifdef REFCLOCK
 	if (ISREFCLOCKADR(&peer->srcadr)) {
-
+#ifdef REFCLOCK
 		/*
 		 * We let the reference clock support do clock
 		 * dependent initialization.  This includes setting
@@ -925,8 +925,14 @@ newpeer(
 			free_peer(peer, 0);
 			return NULL;
 		}
+#else /* REFCLOCK */
+		msyslog(LOG_ERR, "refclock %s isn't supported. ntpd was compiled without refclock support.",
+			stoa(&peer->srcadr));
+		set_peerdstadr(peer, NULL);
+		free_peer(peer, 0);
+		return NULL;
+#endif /* REFCLOCK */
 	}
-#endif
 
 	/*
 	 * Put the new peer in the hash tables.
@@ -950,7 +956,7 @@ newpeer(
 
 
 /*
- * peer_clr_stats - clear peer module statiistics counters
+ * peer_clr_stats - clear peer module statistics counters
  */
 void
 peer_clr_stats(void)
@@ -1032,3 +1038,21 @@ findmanycastpeer(
 
 	return peer;
 }
+
+/* peer_cleanup - clean peer list prior to shutdown */
+void peer_cleanup(void)
+{
+        struct peer *peer;
+        associd_t assoc;
+
+        for (assoc = initial_association_ID; assoc != current_association_ID; assoc++) {
+            if (assoc != 0U) {
+                peer = findpeerbyassoc(assoc);
+                if (peer != NULL)
+                    unpeer(peer);
+            }
+        }
+        peer = findpeerbyassoc(current_association_ID);
+        if (peer != NULL)
+            unpeer(peer);
+}
