@@ -6,11 +6,12 @@
 
 #ifndef VSNPRINTF_PERCENT_M
 // format_errmsg() is normally private to msyslog.c
-void	format_errmsg	(char *, size_t, const char *, int);
+void format_errmsg(char *, size_t, const char *, int);
 #endif
 
 
-void test_msnprintf(void) {
+void
+test_msnprintf(void) {
 #define FMT_PREFIX "msyslog.cpp ENOENT: "
 	char	exp_buf[512];
 	char	act_buf[512];
@@ -21,6 +22,7 @@ void test_msnprintf(void) {
 			   strerror(ENOENT));
 	errno = ENOENT;
 	act_cnt = msnprintf(act_buf, sizeof(act_buf), FMT_PREFIX "%m");
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 	TEST_ASSERT_EQUAL_STRING(exp_buf, act_buf);
 }
@@ -36,6 +38,7 @@ test_msnprintfLiteralPercentm(void)
 	exp_cnt = snprintf(exp_buf, sizeof(exp_buf), "%%m");
 	errno = ENOENT;
 	act_cnt = msnprintf(act_buf, sizeof(act_buf), "%%m");
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 	TEST_ASSERT_EQUAL_STRING(exp_buf, act_buf);
 }
@@ -50,6 +53,7 @@ test_msnprintfBackslashLiteralPercentm(void) {
 	exp_cnt = snprintf(exp_buf, sizeof(exp_buf), "\%%m");
 	errno = ENOENT;
 	act_cnt = msnprintf(act_buf, sizeof(act_buf), "\%%m");
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 	TEST_ASSERT_EQUAL_STRING(exp_buf, act_buf);
 }
@@ -65,6 +69,7 @@ test_msnprintfBackslashPercent(void) {
 			   strerror(ENOENT));
 	errno = ENOENT;
 	act_cnt = msnprintf(act_buf, sizeof(act_buf), "\%m");
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 	TEST_ASSERT_EQUAL_STRING(exp_buf, act_buf);
 }
@@ -81,6 +86,7 @@ test_msnprintfHangingPercent(void) {
 	ZERO(act_buf);
 	exp_cnt = snprintf(exp_buf, sizeof(exp_buf), "%s", fmt);
 	act_cnt = msnprintf(act_buf, sizeof(act_buf), "%s", fmt);
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 	TEST_ASSERT_EQUAL_STRING(exp_buf, act_buf);
 	TEST_ASSERT_EQUAL_STRING("", act_buf + 1 + strlen(act_buf));
@@ -94,6 +100,7 @@ test_format_errmsgHangingPercent(void) {
 
 	ZERO(act_buf);
 	format_errmsg(act_buf, sizeof(act_buf), fmt, ENOENT);
+
 	TEST_ASSERT_EQUAL_STRING(fmt, act_buf);
 	TEST_ASSERT_EQUAL_STRING("", act_buf + 1 + strlen(act_buf));
 #else
@@ -109,6 +116,7 @@ test_msnprintfNullTarget(void) {
 	exp_cnt = snprintf(NULL, 0, "%d", 123);
 	errno = ENOENT;
 	act_cnt = msnprintf(NULL, 0, "%d", 123);
+
 	TEST_ASSERT_EQUAL(exp_cnt, act_cnt);
 }
 
@@ -125,6 +133,7 @@ test_msnprintfTruncate(void) {
 	exp_cnt = snprintf(exp_buf, 3, "%s", strerror(ENOENT));
 	errno = ENOENT;
 	act_cnt = msnprintf(act_buf, 3, "%m");
+
 	TEST_ASSERT_EQUAL('\0', exp_buf[2]);
 	TEST_ASSERT_EQUAL('\0', act_buf[2]);
 	TEST_ASSERT_TRUE(act_cnt > 0);
